From 4ea06a374da4a8d2dfa86f949ded3f1661f4679d Mon Sep 17 00:00:00 2001
From: Alexis de Lattre <>
Date: Mon, 22 Aug 2011 19:57:59 +0200
Subject: [PATCH] [IMP] base_scheduler_creator clean code
---
base_scheduler_creator/__init__.py | 34 +++++++--------
base_scheduler_creator/__openerp__.py | 41 ++++++++++---------
base_scheduler_creator/schedulder_creator.py | 32 ++++++++-------
base_scheduler_creator/schedulder_creator.xml | 3 +-
4 files changed, 58 insertions(+), 52 deletions(-)
diff --git a/base_scheduler_creator/__init__.py b/base_scheduler_creator/__init__.py
index 2f6725d1b..8073589c1 100755
--- a/base_scheduler_creator/__init__.py
+++ b/base_scheduler_creator/__init__.py
@@ -1,20 +1,22 @@
-# -*- coding: utf-8 -*-
+# -*- encoding: utf-8 -*-
#########################################################################
-# #
-# Copyright (C) 2010 Sébastien Beau #
-# #
-#This program is free software: you can redistribute it and/or modify #
-#it under the terms of the GNU General Public License as published by #
-#the Free Software Foundation, either version 3 of the License, or #
-#(at your option) any later version. #
-# #
-#This program is distributed in the hope that it will be useful, #
-#but WITHOUT ANY WARRANTY; without even the implied warranty of #
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the #
-#GNU General Public License for more details. #
-# #
-#You should have received a copy of the GNU General Public License #
-#along with this program. If not, see . #
+#
+# Base scheduler creator module for OpenERP
+# Copyright (C) 2010 Sébastien Beau
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program. If not, see .
+#
#########################################################################
import schedulder_creator
diff --git a/base_scheduler_creator/schedulder_creator.py b/base_scheduler_creator/schedulder_creator.py
index 4a7e423a4..47e611001 100755
--- a/base_scheduler_creator/schedulder_creator.py
+++ b/base_scheduler_creator/schedulder_creator.py
@@ -1,20 +1,22 @@
# -*- encoding: utf-8 -*-
#########################################################################
-# #
-# Copyright (C) 2010 Sébastien Beau #
-# #
-#This program is free software: you can redistribute it and/or modify #
-#it under the terms of the GNU General Public License as published by #
-#the Free Software Foundation, either version 3 of the License, or #
-#(at your option) any later version. #
-# #
-#This program is distributed in the hope that it will be useful, #
-#but WITHOUT ANY WARRANTY; without even the implied warranty of #
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the #
-#GNU General Public License for more details. #
-# #
-#You should have received a copy of the GNU General Public License #
-#along with this program. If not, see . #
+#
+# Base scheduler creator module for OpenERP
+# Copyright (C) 2010 Sébastien Beau
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program. If not, see .
+#
#########################################################################
from osv import fields,osv
diff --git a/base_scheduler_creator/schedulder_creator.xml b/base_scheduler_creator/schedulder_creator.xml
index b3f3817c1..1abe0f424 100755
--- a/base_scheduler_creator/schedulder_creator.xml
+++ b/base_scheduler_creator/schedulder_creator.xml
@@ -5,7 +5,6 @@
scheduler.creator.wizard.form
- 20
scheduler.creator.wizard
form
@@ -21,7 +20,7 @@
- create a scheduler
+ Create a scheduler
ir.actions.act_window
scheduler.creator.wizard
form
diff --git a/base_scheduler_creator/__openerp__.py b/base_scheduler_creator/__openerp__.py
index 8a22ed197..ff1235484 100755
--- a/base_scheduler_creator/__openerp__.py
+++ b/base_scheduler_creator/__openerp__.py
@@ -1,33 +1,36 @@
-# -*- coding: utf-8 -*-
+# -*- encoding: utf-8 -*-
#########################################################################
# #
# Copyright (C) 2010 Sébastien Beau #
# #
#This program is free software: you can redistribute it and/or modify #
#it under the terms of the GNU General Public License as published by #
#the Free Software Foundation, either version 3 of the License, or #
#(at your option) any later version. #
# #
#This program is distributed in the hope that it will be useful, #
#but WITHOUT ANY WARRANTY; without even the implied warranty of #
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the #
#GNU General Public License for more details. #
# #
#You should have received a copy of the GNU General Public License #
#along with this program. If not, see . #
#########################################################################
+
{
"name" : "base_scheduler_creator",
"version" : "1.0",
- "depends" : [],
+ "license": "AGPL-3",
+ "depends" : ["base"],
"author" : "Akretion",
"description": """Allows the automatic creation of a scheduler.""",
"website" : "http://www.akretion.com/",
- "category" : "Customer Modules",
+ "category" : "Generic Modules/Other",
"init_xml" : [],
"demo_xml" : [],
"update_xml" : ["schedulder_creator.xml"],
"active": False,
"installable": True,
-
}
@@ -1,33 +1,36 @@
#########################################################################
-# #
-# Copyright (C) 2010 Sébastien Beau #
-# #
-#This program is free software: you can redistribute it and/or modify #
-#it under the terms of the GNU General Public License as published by #
-#the Free Software Foundation, either version 3 of the License, or #
-#(at your option) any later version. #
-# #
-#This program is distributed in the hope that it will be useful, #
-#but WITHOUT ANY WARRANTY; without even the implied warranty of #
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the #
-#GNU General Public License for more details. #
-# #
-#You should have received a copy of the GNU General Public License #
-#along with this program. If not, see . #
+#
+# Base scheduler creator module for OpenERP
+# Copyright (C) 2010 Sébastien Beau
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program. If not, see .
+#
#########################################################################